@@ -37,6 +37,26 @@ class ShippingPartnerCodes(object):
     # 闪送
     SS = "ss"
 
+    # code to name
+    CODE_2_NAME_MAP = {
+        SF: "顺丰",
+        SFTCJS: "顺丰同城急送",
+        YTO: "圆通",
+        ZTO: "中通",
+        STO: "申通",
+        EMS: "EMS",
+        YZPY: "邮政",
+        YD: "韵达",
+        ZJS: "宅急送",
+        JD: "京东",
+        DBL: "德邦",
+        HTKY: "百世快递",
+        HHTT: "天天",
+        OTHERS: "其它",
+        SHOP: "专柜代发",
+        SS: "闪送",
+    }
+
 
 # 快递公司代号与中文对照
 ShippingPartnerCodes_DICT = {
